@@ -114,6 +114,31 @@ callback_unref (gpointer callback)
   }
 }
 
+/**
+ * atspi_event_listener_new:
+ * @callback: (scope notified): An #AtspiEventListenerSimpleCB to be called
+ * when an event is fired.
+ * @user_data: (closure): data to pass to the callback.
+ * @callback_destroyed: A #GDestroyNotify called when the listener is freed
+ * and data associated with the callback should be freed.  Can be NULL.
+ *
+ * Creates a new #AtspiEventListener associated with a specified @callback.
+ *
+ * Returns: (transfer full): A new #AtspiEventListener.
+ */
+AtspiEventListener *
+atspi_event_listener_new (AtspiEventListenerCB callback,
+                                 gpointer user_data,
+                                 GDestroyNotify callback_destroyed)
+{
+  AtspiEventListener *listener = g_object_new (ATSPI_TYPE_EVENT_LISTENER, NULL);
+  listener->callback = callback;
+  callback_ref (callback, callback_destroyed);
+  listener->user_data = user_data;
+  listener->cb_destroyed = callback_destroyed;
+  return listener;
+}
+
 /**
  * atspi_event_listener_new_simple:
  * @callback: (scope notified): An #AtspiEventListenerSimpleCB to be called
@@ -121,8 +146,9 @@ callback_unref (gpointer callback)
  * @callback_destroyed: A #GDestroyNotify called when the listener is freed
  * and data associated with the callback should be freed.  Can be NULL.
  *
+ * Creates a new #AtspiEventListener associated with a specified @callback.
  * Returns: (transfer full): A new #AtspiEventListener.
- */
+ **/
 AtspiEventListener *
 atspi_event_listener_new_simple (AtspiEventListenerSimpleCB callback,
                                  GDestroyNotify callback_destroyed)
@@ -359,7 +385,7 @@ oom:
 static void
 listener_entry_free (EventListenerEntry *e)
 {
-  gpointer callback = (e->callback == remove_datum ? e->user_data : e->callback);
+  gpointer callback = (e->callback == remove_datum ? (gpointer)e->user_data : (gpointer)e->callback);
   g_free (e->category);
   g_free (e->name);
   if (e->detail) g_free (e->detail);
@@ -378,6 +404,8 @@ listener_entry_free (EventListenerEntry *e)
  *            and toolkit events (e.g. "Gtk", "AWT").
  *            Examples: "focus:", "Gtk:GtkWidget:button_press_event".
  *
+ * Adds an in-process callback function to an existing #AtspiEventListener.
+ *
  * Legal object event types:
  *
  *    (property change events)
@@ -445,13 +473,13 @@ listener_entry_free (EventListenerEntry *e)
  *            mouse:b3p
  *            mouse:b3r
  *
- * NOTE: this string may be UTF-8, but should not contain byte value 56
+ * NOTE: this character string may be UTF-8, but should not contain byte 
+ * value 56
  *            (ascii ':'), except as a delimiter, since non-UTF-8 string
  *            delimiting functions are used internally.
  *            In general, listening to
  *            toolkit-specific events is not recommended.
  *
- * Add an in-process callback function to an existing AtspiEventListener.
  *
  * Returns: #TRUE if successful, otherwise #FALSE.
  **/
@@ -471,14 +499,19 @@ atspi_event_listener_register (AtspiEventListener *listener,
 
 /**
  * atspi_event_listener_register_from_callback:
- * @callback: (scope notified): the #AtspiEventListenerCB to be registered against
- *            an event type.
+ * @callback: (scope notified): the #AtspiEventListenerCB to be registered 
+ * against an event type.
  * @user_data: (closure): User data to be passed to the callback.
  * @callback_destroyed: A #GDestroyNotify called when the callback is destroyed.
  * @event_type: a character string indicating the type of events for which
  *            notification is requested.  See #atspi_event_listener_register
  * for a description of the format.
- */
+ * 
+ * Registers an #AtspiEventListenerCB against an @event_type.
+ *
+ * Returns: #TRUE if successfull, otherwise #FALSE.
+ *
+ **/
 gboolean
 atspi_event_listener_register_from_callback (AtspiEventListenerCB callback,
 				             void *user_data,
@@ -507,7 +540,7 @@ atspi_event_listener_register_from_callback (AtspiEventListenerCB callback,
   e->callback = callback;
   e->user_data = user_data;
   e->callback_destroyed = callback_destroyed;
-  callback_ref (callback == remove_datum ? user_data : callback,
+  callback_ref (callback == remove_datum ? (gpointer)user_data : (gpointer)callback,
                 callback_destroyed);
   if (!convert_event_type_to_dbus (event_type, &e->category, &e->name, &e->detail, &matchrule))
   {
@@ -557,7 +590,10 @@ atspi_event_listener_register_from_callback (AtspiEventListenerCB callback,
  *            and toolkit events (e.g. "Gtk", "AWT").
  *            Examples: "focus:", "Gtk:GtkWidget:button_press_event".
  *
- * Like atspi_event_listener_register, but callback takes no user_data.
+ * Registers an #AtspiEventListenetSimpleCB. The method is similar to 
+ * #atspi_event_listener_register, but @callback takes no user_data.
+ *
+ * Returns: #TRUE if successfull, otherwise #FALSE.
  **/
 gboolean
 atspi_event_listener_register_no_data (AtspiEventListenerSimpleCB callback,
@@ -584,7 +620,7 @@ is_superset (const gchar *super, const gchar *sub)
  * @event_type: a string specifying the event type for which this
  *             listener is to be deregistered.
  *
- * deregisters an #AtspiEventListener from the registry, for a specific
+ * Deregisters an #AtspiEventListener from the registry, for a specific
  *             event type.
  *
  * Returns: #TRUE if successful, otherwise #FALSE.
@@ -607,7 +643,7 @@ atspi_event_listener_deregister (AtspiEventListener *listener,
  * @event_type: a string specifying the event type for which this
  *             listener is to be deregistered.
  *
- * deregisters an #AtspiEventListenerCB from the registry, for a specific
+ * Deregisters an #AtspiEventListenerCB from the registry, for a specific
  *             event type.
  *
  * Returns: #TRUE if successful, otherwise #FALSE.
@@ -652,12 +688,13 @@ atspi_event_listener_deregister_from_callback (AtspiEventListenerCB callback,
       message = dbus_message_new_method_call (atspi_bus_registry,
 	    atspi_path_registry,
 	    atspi_interface_registry,
-	    "RegisterEvent");
+	    "DeregisterEvent");
       if (!message)
       return FALSE;
       dbus_message_append_args (message, DBUS_TYPE_STRING, &event_type, DBUS_TYPE_INVALID);
       reply = _atspi_dbus_send_with_reply_and_block (message, error);
-      dbus_message_unref (reply);
+      if (reply)
+        dbus_message_unref (reply);
 
       listener_entry_free (e);
     }
@@ -749,7 +786,7 @@ _atspi_send_event (AtspiEvent *e)
 }
 
 DBusHandlerResult
-atspi_dbus_handle_event (DBusConnection *bus, DBusMessage *message, void *data)
+_atspi_dbus_handle_event (DBusConnection *bus, DBusMessage *message, void *data)
 {
   char *detail = NULL;
   const char *category = dbus_message_get_interface (message);
